@@ -29,9 +29,8 @@
 
 QString SignedBitfieldDataInformation::valueString() const
 {
-    if (!mWasAbleToRead)
-        return i18nc("invalid value (out of range)", "&lt;invalid&gt;");
-    return SIntDataInformation<qint64>::valueString(mValue.longValue);
+    Q_ASSERT(mWasAbleToRead);
+    return SIntDataInformationMethods<qint64>::staticValueString(mValue.longValue);
 }
 
 QWidget* SignedBitfieldDataInformation::createEditWidget(QWidget* parent) const
@@ -69,7 +68,7 @@ QScriptValue SignedBitfieldDataInformation::valueAsQScriptValue() const
 void SignedBitfieldDataInformation::setValue(AllPrimitiveTypes newVal)
 {
     //check that values are not too large
-    Q_ASSERT((newVal.longValue < 0 && (newVal.longValue | ~mask()) == newVal.longValue)
+    Q_ASSERT((newVal.longValue < 0 && (newVal.longValue | ~mask()) == newVal.ulongValue)
         || (newVal.ulongValue & mask()) == newVal.ulongValue);
     mValue = newVal.ulongValue & mask();
     //check if MSB is set -> negative -> sign extend
@@ -77,3 +76,8 @@ void SignedBitfieldDataInformation::setValue(AllPrimitiveTypes newVal)
         mValue = mValue.ulongValue | (~mask());
     }
 }
+
+AllPrimitiveTypes SignedBitfieldDataInformation::fromVariant(const QVariant& variant, bool* ok) const
+{
+    return AllPrimitiveTypes(variant.toLongLong(ok));
+}
