@@ -26,6 +26,7 @@
 // lib
 #include "oktetakastencontrollers_export.h"
 // tool
+#include "structviewpreferences.h"
 #include "datatypes/topleveldatainformation.h"
 // Kasten core
 #include <abstracttool.h>
@@ -63,6 +64,7 @@ public:
 public:
     QSysInfo::Endian byteOrder() const;
     void setByteOrder(QSysInfo::Endian order);
+    KDE_DEPRECATED void setByteOrder(StructViewPreferences::EnumByteOrder::type order);
     int columnCount() const;
     bool setData(const QVariant& value, int role, DataInformation* item, uint row);
     Okteta::AbstractByteArrayModel* byteArrayModel() const;
