@@ -11,14 +11,6 @@
 // own header
 #include "umlwidgetcontroller.h"
 
-// qt includes
-#include <QtCore/QEvent>
-#include <QtCore/QPoint>
-
-// kde includes
-#include <kcursor.h>
-#include <klocale.h>
-
 // app includes
 #include "umlwidget.h"
 #include "umlwidgetlist.h"
@@ -29,6 +21,14 @@
 #include "listpopupmenu.h"
 #include "associationwidget.h"
 #include "cmds.h"
+#include "debug_utils.h"
+
+// kde includes
+#include <kcursor.h>
+#include <klocale.h>
+
+// qt includes
+#include <QEvent>
 
 /**
  * Constructor for UMLWidgetController.
@@ -84,9 +84,9 @@ UMLWidgetController::~UMLWidgetController()
  * it's marked to be deselected when releasing the button (provided it wasn't
  * moved or resized).
  *
- * @param me The QMouseEvent event.
+ * @param me The QGraphicsSceneMouseEvent event.
  */
-void UMLWidgetController::mousePressEvent(QMouseEvent *me)
+void UMLWidgetController::mousePressEvent(QGraphicsSceneMouseEvent *me)
 {
     // If there is a button pressed already ignore other press events
     if (m_leftButtonDown || m_middleButtonDown || m_rightButtonDown) {
@@ -179,9 +179,9 @@ void UMLWidgetController::mousePressEvent(QMouseEvent *me)
  * not updated always to be easy on the CPU). Finally, the canvas is resized,
  * and selection bounds updated.
  *
- * @param me The QMouseEvent event.
+ * @param me The QGraphicsSceneMouseEvent event.
  */
-void UMLWidgetController::mouseMoveEvent(QMouseEvent* me)
+void UMLWidgetController::mouseMoveEvent(QGraphicsSceneMouseEvent* me)
 {
     if (!m_leftButtonDown)
         return;
@@ -201,9 +201,9 @@ void UMLWidgetController::mouseMoveEvent(QMouseEvent* me)
         setSelectionBounds();
     }
 
-    QPoint position = getPosition(me);
-    int diffX = position.x() - m_widget->x();
-    int diffY = position.y() - m_widget->y();
+    UMLScenePoint position = getPosition(me);
+    UMLSceneValue diffX = position.x() - m_widget->x();
+    UMLSceneValue diffY = position.y() - m_widget->y();
 
     if ((me->modifiers() & Qt::ShiftModifier) && (me->modifiers() & Qt::ControlModifier)) {
         //Move in Y axis
@@ -254,7 +254,7 @@ void UMLWidgetController::mouseMoveEvent(QMouseEvent* me)
         }
     }
 
-    m_widget->m_scene->resizeCanvasToItems();
+    m_widget->umlScene()->resizeCanvasToItems();
     updateSelectionBounds(diffX, diffY);
 }
 
@@ -295,9 +295,9 @@ void UMLWidgetController::widgetMoved()
  * event at the same position than the cursor was when pressed. Another left
  * button release is also sent.
  *
- * @param me The QMouseEvent event.
+ * @param me The QGraphicsSceneMouseEvent event.
  */
-void UMLWidgetController::mouseReleaseEvent(QMouseEvent *me)
+void UMLWidgetController::mouseReleaseEvent(QGraphicsSceneMouseEvent *me)
 {
     if (me->button() != Qt::LeftButton && me->button() != Qt::RightButton) {
         if (m_middleButtonDown) {
@@ -334,8 +334,8 @@ void UMLWidgetController::mouseReleaseEvent(QMouseEvent *me)
             }
 
             if (m_inResizeArea) {
-                m_inResizeArea = false;
-                m_widget->m_scene->view()->setCursor(Qt::ArrowCursor);
+                m_inResizeArea = false; 
+                m_widget->m_scene->activeView()->setCursor(Qt::ArrowCursor);
             } else {
                 m_inMoveArea = false;
             }
@@ -345,20 +345,36 @@ void UMLWidgetController::mouseReleaseEvent(QMouseEvent *me)
             m_rightButtonDown = false;
             showPopupMenu(me);
         } else if (m_leftButtonDown) {
+#ifdef Q3CANVAS_IMPLEMENTATION
             //Cancel move/edit
-            QMouseEvent move(QMouseEvent::MouseMove,
+            QGraphicsSceneMouseEvent move(QGraphicsSceneMouseEvent::MouseMove,
                              QPoint(m_oldX + m_pressOffsetX, m_oldY + m_pressOffsetY),
                              Qt::LeftButton, Qt::NoButton, Qt::NoModifier);
             mouseMoveEvent(&move);
-            QMouseEvent release(QMouseEvent::MouseButtonRelease,
+            QGraphicsSceneMouseEvent release(QGraphicsSceneMouseEvent::MouseButtonRelease,
                                 QPoint(m_oldX + m_pressOffsetX, m_oldY + m_pressOffsetY),
                                 Qt::LeftButton, Qt::NoButton, Qt::NoModifier);
             mouseReleaseEvent(&release);
+#endif
+#ifdef QGRAPHICS_IMPLEMENTATION
+            QGraphicsSceneMouseEvent move = new QGraphicsSceneMouseEvent(type);
+            move->setPos(me->pos());
+            move->setScenePosome->scenePos());
+            move->setScreenPos(me->screenPos());
+            move->setLastPos(me->lastPos());
+            move->setLastScenePos(me->lastScenePos());
+            move->setLastScreenPos(me->lastScreenPos());
+            move->setButtons(me->buttons());
+            move->setButton(me->button());
+            move->setModifiers(me->modifiers());
+            mouseMoveEvent(&move);
+            mouseReleaseEvent(&move);
+#endif
         }
     }
 
     //TODO Copied from old code. Does it really work as intended?
-    UMLWidget *bkgnd = m_widget->m_scene->widgetAt(me->pos());
+    UMLWidget *bkgnd = m_widget->m_scene->widgetAt(me->scenePos());
     if (bkgnd) {
         //uDebug() << "setting Z to " << bkgnd->z() + 1;
         m_widget->setZ(bkgnd->z() + 1);
@@ -379,9 +395,9 @@ UMLWidget* UMLWidgetController::getWidget()
  * doMouseDoubleClick.
  * @see doMouseDoubleClick
  *
- * @param me The QMouseEvent event.
+ * @param me The QGraphicsSceneMouseEvent event.
  */
-void UMLWidgetController::mouseDoubleClickEvent(QMouseEvent *me)
+void UMLWidgetController::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *me)
 {
     if (me->button() != Qt::LeftButton) {
         return;
@@ -400,7 +416,7 @@ void UMLWidgetController::mouseDoubleClickEvent(QMouseEvent *me)
  * @param me The QMouseEVent to check.
  * @return true if the mouse is in resize area, false otherwise.
  */
-bool UMLWidgetController::isInResizeArea(QMouseEvent *me)
+bool UMLWidgetController::isInResizeArea(QGraphicsSceneMouseEvent *me)
 {
     int m = 10;
     const int w = m_widget->width();
@@ -412,12 +428,12 @@ bool UMLWidgetController::isInResizeArea(QMouseEvent *me)
         m = 2;
 
     if (m_widget->m_resizable &&
-            me->x() >= (m_widget->x() + w - m) &&
-            me->y() >= (m_widget->y() + h - m)) {
-        m_widget->m_scene->view()->setCursor(getResizeCursor());
+            me->scenePos().x() >= (m_widget->x() + w - m) &&
+            me->scenePos().y() >= (m_widget->y() + h - m)) {
+        m_widget->m_scene->activeView()->setCursor(getResizeCursor());
         return true;
     } else {
-        m_widget->m_scene->view()->setCursor(Qt::ArrowCursor);
+        m_widget->m_scene->activeView()->setCursor(Qt::ArrowCursor);
         return false;
     }
 }
@@ -445,7 +461,7 @@ QCursor UMLWidgetController::getResizeCursor()
  * @param newW The new width for the widget.
  * @param newH The new height for the widget.
  */
-void UMLWidgetController::resizeWidget(int newW, int newH)
+void UMLWidgetController::resizeWidget(UMLSceneValue newW, UMLSceneValue newH)
 {
     m_widget->setSize(newW, newH);
 }
@@ -467,7 +483,7 @@ void UMLWidgetController::resizeWidget(int newW, int newH)
  * @param diffX The difference between current X position and new X position.
  * @param diffY The difference between current Y position and new Y position.
  */
-void UMLWidgetController::moveWidgetBy(int diffX, int diffY)
+void UMLWidgetController::moveWidgetBy(UMLSceneValue diffX, UMLSceneValue diffY)
 {
     m_widget->setX(m_widget->x() + diffX);
     m_widget->setY(m_widget->y() + diffY);
@@ -490,7 +506,7 @@ void UMLWidgetController::moveWidgetBy(int diffX, int diffY)
  * @param diffX The difference between current X position and new X position.
  * @param diffY The difference between current Y position and new Y position.
  */
-void UMLWidgetController::constrainMovementForAllWidgets(int &diffX, int &diffY)
+void UMLWidgetController::constrainMovementForAllWidgets(UMLSceneValue &diffX, UMLSceneValue &diffY)
 {
     Q_UNUSED(diffX); Q_UNUSED(diffY);
 }
@@ -506,9 +522,9 @@ void UMLWidgetController::constrainMovementForAllWidgets(int &diffX, int &diffY)
  * don't have an UMLObject representation) there's no need to override
  * the method, it simply does nothing.
  *
- * @param me The QMouseEvent which triggered the double click event.
+ * @param me The QGraphicsSceneMouseEvent which triggered the double click event.
  */
-void UMLWidgetController::doMouseDoubleClick(QMouseEvent *)
+void UMLWidgetController::doMouseDoubleClick(QGraphicsSceneMouseEvent *)
 {
     if (!m_widget || !m_widget->m_pMenu)
         return;
@@ -522,7 +538,7 @@ void UMLWidgetController::doMouseDoubleClick(QMouseEvent *)
 void UMLWidgetController::resetSelection()
 {
     m_widget->m_scene->clearSelected();
-    m_widget->m_scene->view()->resetToolbar();
+    m_widget->m_scene->resetToolbar();
     m_widget->setSelected(false);
 
     m_wasSelected = false;
@@ -531,9 +547,9 @@ void UMLWidgetController::resetSelection()
 /**
  * Selects the widget and clears the other selected widgets, if any.
  *
- * @param me The QMouseEvent which made the selection.
+ * @param me The QGraphicsSceneMouseEvent which made the selection.
  */
-void UMLWidgetController::selectSingle(QMouseEvent *me)
+void UMLWidgetController::selectSingle(QGraphicsSceneMouseEvent *me)
 {
     m_widget->m_scene->clearSelected();
 
@@ -545,12 +561,11 @@ void UMLWidgetController::selectSingle(QMouseEvent *me)
 /**
  * Selects the widget and adds it to the list of selected widgets.
  *
- * @param me The QMouseEvent which made the selection.
+ * @param me The QGraphicsSceneMouseEvent which made the selection.
  */
-void UMLWidgetController::selectMultiple(QMouseEvent *me)
+void UMLWidgetController::selectMultiple(QGraphicsSceneMouseEvent *me)
 {
-    m_widget->m_selected = true;
-    m_widget->setSelected(m_widget->m_selected);
+    m_widget->setSelected(true);
     m_widget->m_scene->setSelected(m_widget, me);
 
     m_wasSelected = true;
@@ -559,12 +574,11 @@ void UMLWidgetController::selectMultiple(QMouseEvent *me)
 /**
  * Deselects the widget and removes it from the list of selected widgets.
  *
- * @param me The QMouseEvent which made the selection.
+ * @param me The QGraphicsSceneMouseEvent which made the selection.
  */
-void UMLWidgetController::deselect(QMouseEvent *me)
+void UMLWidgetController::deselect(QGraphicsSceneMouseEvent *me)
 {
-    m_widget->m_selected = false;
-    m_widget->setSelected(m_widget->m_selected);
+    m_widget->setSelected(false);
     m_widget->m_scene->setSelected(m_widget, me);
     //m_wasSelected is false implicitly, no need to set it again
 }
@@ -579,12 +593,12 @@ void UMLWidgetController::deselect(QMouseEvent *me)
  * resize begins. However, parent method (that is, this method) must be
  * called in the overridden method.
  *
- * @param me The QMouseEvent to get the offset from.
+ * @param me The QGraphicsSceneMouseEvent to get the offset from.
  */
-void UMLWidgetController::saveWidgetValues(QMouseEvent *me)
+void UMLWidgetController::saveWidgetValues(QGraphicsSceneMouseEvent *me)
 {
-    m_pressOffsetX = me->x() - m_widget->x();
-    m_pressOffsetY = me->y() - m_widget->y();
+    m_pressOffsetX = me->scenePos().x() - m_widget->x();
+    m_pressOffsetY = me->scenePos().y() - m_widget->y();
 
     m_prevX = m_oldX = m_widget->x();
     m_prevY = m_oldY = m_widget->y();
@@ -661,16 +675,16 @@ void UMLWidgetController::updateSelectionBounds(int diffX, int diffY)
  * in resize area when pressed.
  * Resizing can be constrained to an specific axis using control and shift buttons.
  *
- * @param me The QMouseEvent to get the values from.
+ * @param me The QGraphicsSceneMouseEvent to get the values from.
  */
-void UMLWidgetController::resize(QMouseEvent *me)
+void UMLWidgetController::resize(QGraphicsSceneMouseEvent *me)
 {
     UMLApp::app()->document()->writeToStatusBar(i18n("Hold shift or ctrl to move in X axis. Hold shift and control to move in Y axis. Right button click to cancel resize."));
 
     m_resized = true;
 
-    int newW = m_oldW + me->x() - m_widget->x() - m_pressOffsetX;
-    int newH = m_oldH + me->y() - m_widget->y() - m_pressOffsetY;
+    UMLSceneValue newW = m_oldW + me->scenePos().x() - m_widget->x() - m_pressOffsetX;
+    UMLSceneValue newH = m_oldH + me->scenePos().y() - m_widget->y() - m_pressOffsetY;
 
     if ((me->modifiers() & Qt::ShiftModifier) && (me->modifiers() & Qt::ControlModifier)) {
         //Move in Y axis
@@ -801,10 +815,10 @@ int UMLWidgetController::getBiggestY(const UMLWidgetList &widgetList)
  * m_widget->get{X,Y}(), the previous position m_old{X,Y}, and the
  * mouse press offset m_pressOffset{X,Y}.
  *
- * @param me The QMouseEvent for which to get the adjusted position.
- * @return A QPoint with the adjusted position.
+ * @param me The QGraphicsSceneMouseEvent for which to get the adjusted position.
+ * @return A UMLScenePoint with the adjusted position.
  */
-QPoint UMLWidgetController::getPosition(QMouseEvent* me)
+UMLScenePoint UMLWidgetController::getPosition(QGraphicsSceneMouseEvent* me)
 {
     /*
     uDebug() << "me->x=" << me->x()
@@ -814,10 +828,10 @@ QPoint UMLWidgetController::getPosition(QMouseEvent* me)
         << " m_widget->getY=" << m_widget->y() << ", m_oldY=" << m_oldY
         << ", m_pressOffsetY=" << m_pressOffsetY << endl;
      */
-    int newX = me->x() + m_widget->x() - m_prevX - m_pressOffsetX;
-    int newY = me->y() + m_widget->y() - m_prevY - m_pressOffsetY;
-    int maxX = m_widget->m_scene->width();
-    int maxY = m_widget->m_scene->height();
+    UMLSceneValue newX = me->scenePos().x() + m_widget->x() - m_prevX - m_pressOffsetX;
+    UMLSceneValue newY = me->scenePos().y() + m_widget->y() - m_prevY - m_pressOffsetY;
+    UMLSceneValue maxX = m_widget->m_scene->width();
+    UMLSceneValue maxY = m_widget->m_scene->height();
 
     m_prevX = newX;
     m_prevY = newY;
@@ -838,37 +852,37 @@ QPoint UMLWidgetController::getPosition(QMouseEvent* me)
         //uDebug() << "got into cond.4";
         newY = maxY - (m_maxSelectedY - m_widget->y());
     }
-    return QPoint(newX, newY);
+    return UMLScenePoint(newX, newY);
 }
 
 /**
- * Returns a QPoint with the new X and Y position difference of the mouse event
+ * Returns a UMLScenePoint with the new X and Y position difference of the mouse event
  * respect to the position of the widget.
  *
- * @param me The QMouseEvent to get the position to compare.
- * @return A QPoint with the position difference.
+ * @param me The QGraphicsSceneMouseEvent to get the position to compare.
+ * @return A UMLScenePoint with the position difference.
  */
-QPoint UMLWidgetController::getPositionDifference(QMouseEvent* me)
+UMLScenePoint UMLWidgetController::getPositionDifference(QGraphicsSceneMouseEvent* me)
 {
-    QPoint newPoint = getPosition(me);
+    UMLScenePoint newPoint = getPosition(me);
     const int diffX = newPoint.x() - m_widget->x();
     const int diffY = newPoint.y() - m_widget->y();
-    return QPoint(diffX, diffY);
+    return UMLScenePoint(diffX, diffY);
 }
 
 /**
  * Shows the widget popup menu where the mouse event points to.
  *
- * @param me The QMouseEvent which triggered the showing.
+ * @param me The QGraphicsSceneMouseEvent which triggered the showing.
  */
-void UMLWidgetController::showPopupMenu(QMouseEvent *me)
+void UMLWidgetController::showPopupMenu(QGraphicsSceneMouseEvent *me)
 {
     //TODO why this condition?
     if (m_widget->m_pMenu) {
         return;
     }
     ListPopupMenu* menu = m_widget->setupPopupMenu();
-    menu->popup(me->globalPos());
+    menu->popup(me->screenPos());
 }
 
 /**
