@@ -41,16 +41,18 @@
 #include <kmenu.h>
 
 // qt includes
-#include <QtGui/QMouseEvent>
-#include <QtGui/QKeyEvent>
-#include <QtGui/QKeySequence>
-#include <QtGui/QMenu>
-#include <QtGui/QColor>
-#include <QtGui/QLabel>
-#include <QtGui/QBrush>
-#include <QtGui/QLayout>
-#include <QtCore/QPointer>
-#include <QtCore/QRegExp>
+#include <QBrush>
+#include <QColor>
+#include <QKeyEvent>
+#include <QKeySequence>
+#include <QLabel>
+#include <QLayout>
+#include <QMenu>
+#include <QMouseEvent>
+#include <QPointer>
+#include <QRegExp>
+
+DEBUG_REGISTER(CodeEditor)
 
 /**
  * Constructor.
@@ -933,8 +935,6 @@ void CodeEditor::slotRedrawText()
  */
 void CodeEditor::init(CodeViewerDialog * parentDlg, CodeDocument * parentDoc)
 {
-    DEBUG_REGISTER(DBG_SRC);
-
     // safety to insure that we are up to date
     parentDoc->synchronize();
 
