@@ -13,10 +13,10 @@
 
 #include "umlviewimageexportermodel.h"
 
-#include <QtCore/QString>
-
 #include <kurl.h>
 
+#include <QString>
+
 class UMLScene;
 class UMLFileDialog;
 
